agentle.mcp.servers.stdio\_mcp\_server
======================================

.. automodule:: agentle.mcp.servers.stdio_mcp_server

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
      PrivateAttr
      TypedDict
      override
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      Callable
      MCPServerProtocol
      MutableMapping
      Sequence
      StdioMCPServer
   